local M = {}

local helper = require('scenario/scenariohelper')
local logTag = 'Drive_The_Pigeon_VII'

local finalWaypointName = 'way_30'
local playerInstance = 'scenario_player0'
local running = false
local playerWon = false
local aiWon = false

local function reset()
  running = false
  playerWon = false
  aiWon = false
end

local function fail(reason)
  scenario_scenarios.finish({failed = reason})
  reset()
end

local function success(reason)
  scenario_scenarios.finish({msg = reason})
  reset()
end

local function onRaceStart()
  -- log('I', logTag,'onRaceStart called')
  reset()

  local arg = {vehicleName = 'scenario_opponent',
              waypoints = {'way_1', 'way_2', 'way_3', 'way_4', 'way_5', 'way_6', 'way_7',
			               'way_8', 'way_9', 'way_10', 'way_11', 'way_12', 'way_13', 'way_14',
                           'way_15', 'way_16', 'way_17', 'way_18', 'way_19', 'way_20', 'way_21',
                           'way_22', 'way_23', 'way_24', 'way_25', 'way_26', 'way_27', 'way_28',
						   'way_29',finalWaypointName},
              aggression = 0.7, -- aggression here acts as a multiplier to the Ai default aggression i.e. 0.7.
              aggressionMode = 'rubberBand' -- Aggression decreases with distance from opponent
              }

  helper.setAiPath(arg)

  scenario_scenarios.trackVehicleMovementAfterDamage(playerInstance, {waitTimerLimit=2})

	running = true
end

local function onRaceWaypointReached(data)
  --log('I', logTag,'onRaceWaypointReached called ')
  --dump(data)
  if data.waypointName == finalWaypointName then
    if data.vehicleName == playerInstance and not aiWon then
      playerWon = true
    elseif data.vehicleName == aiInstance and not playerWon then
      aiWon = true
    end
  end
end

local function onRaceResult()
  if playerWon then
    success('Man, you are tough competitor.')
  else
    fail('Loser')
  end
end

local function onVehicleStoppedMoving(vehicleID, damaged)
  if running then
    local playerVehicleID = scenetree.findObject(playerInstance):getID()
    if vehicleID == playerVehicleID and damaged then
      if not playerWon then
        fail('Want to race or not??')
      end
    end
  end
end

M.onRaceStart = onRaceStart
M.onRaceWaypointReached = onRaceWaypointReached
M.onRaceResult = onRaceResult
M.onVehicleStoppedMoving = onVehicleStoppedMoving
return M